# -*- coding: utf-8 -*-

from rest_framework import serializers
from thx.api.serializers import (
    ThuxCreateSerializerMixin, ThuxDisableSerializerMixin, ThuxEnableSerializerMixin, ThuxListSerializerMixin,
    ThuxPartialUpdateSerializerMixin, ThuxRetrieveSerializerMixin, ThuxUpdateSerializerMixin,
)
from thx.role.core.serializers import ThuxRoleSerializerMixin

from ... import models


# GENERIC TEMPLATE
class GenericTemplateSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_generic_template'
        model = models.GenericTemplate
        fields = '__all__'


class GenericTemplateListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_generic_template_list'
        model = models.GenericTemplate
        fields = '__all__'


class GenericTemplateRetrieveSerializer(
    ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_template_generic_template_retrieve'
        model = models.GenericTemplate
        fields = '__all__'


class GenericTemplateCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_generic_template_create'
        model = models.GenericTemplate
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = GenericTemplateRetrieveSerializer


class GenericTemplateUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_generic_template_update'
        model = models.GenericTemplate
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = GenericTemplateRetrieveSerializer


class GenericTemplatePartialUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_template_generic_template_partial_update'
        model = models.GenericTemplate
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = GenericTemplateRetrieveSerializer


class GenericTemplateEnableSerializer(ThuxRoleSerializerMixin, ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_generic_template_enable'
        model = models.GenericTemplate
        fields = ()
        response_serializer = GenericTemplateRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class GenericTemplateDisableSerializer(
    ThuxRoleSerializerMixin, ThuxDisableSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_template_generic_template_disable'
        model = models.GenericTemplate
        fields = ()
        response_serializer = GenericTemplateRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class GenericTemplateLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_generic_template_light'
        model = models.GenericTemplate
        fields = ('id', 'status', 'status_display',)


# EMAIL TEMPLATE
class EmailTemplateSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_email_template'
        model = models.EmailTemplate
        fields = '__all__'


class EmailTemplateListSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_email_template_list'
        model = models.EmailTemplate
        fields = '__all__'


class EmailTemplateRetrieveSerializer(
    ThuxRoleSerializerMixin, ThuxRetrieveSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_template_email_template_retrieve'
        model = models.EmailTemplate
        fields = '__all__'


class EmailTemplateCreateSerializer(ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_email_template_create'
        model = models.EmailTemplate
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = EmailTemplateRetrieveSerializer


class EmailTemplateUpdateSerializer(ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_email_template_update'
        model = models.EmailTemplate
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = EmailTemplateRetrieveSerializer


class EmailTemplatePartialUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer
):
    class Meta:
        ref_name = 'v1_template_email_template_partial_update'
        model = models.EmailTemplate
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')
        response_serializer = EmailTemplateRetrieveSerializer


class EmailTemplateEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_email_template_enable'
        model = models.EmailTemplate
        fields = ()
        response_serializer = EmailTemplateRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance


class EmailTemplateDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_email_template_disable'
        model = models.EmailTemplate
        fields = ()
        response_serializer = EmailTemplateRetrieveSerializer

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance


class EmailTemplateLightSerializer(ThuxRoleSerializerMixin, ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_template_email_template_light'
        model = models.EmailTemplate
        fields = ('id', 'status', 'status_display',)
